@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.304';
+$VERSION = '3.305';
 
 ######################################################################
 #### Error Handling
@@ -38,6 +38,7 @@ sub new {
 		options => undef,	# Usually pointer to Verilog::Getopt
 		symbol_table => [],	# Symbol table for Verilog::Parser
  		preproc => 'Verilog::Preproc',
+		remove_defines_without_tick => 0,   # Overriden in SystemC::Netlist
 		#include_open_nonfatal => 0,
 		#keep_comments => 0,
 		use_vars => 1,
@@ -151,11 +152,14 @@ sub remove_defines {
     my $self = shift;
     my $sym = shift;
     # This function is HOT
+    my $xsym = $sym;
     # We only remove defines one level deep, for historical reasons.
-    # We don't require a ` as SystemC also uses this function and doesn't use `.
-    (my $xsym = $sym) =~ s/^\`//;
-    my $val = $self->defvalue_nowarn($xsym);  #Undef if not found
-    $sym = $val if defined $val;
+    # We optionally don't require a ` as SystemC also uses this function and doesn't use `.
+    if ($self->{remove_defines_without_tick} || $xsym =~ /^\`/) {
+	$xsym =~ s/^\`//;
+	my $val = $self->defvalue_nowarn($xsym);  #Undef if not found
+	return $val if defined $val;
+    }
     return $sym;
 }
 
