@@ -53,13 +53,15 @@ public:
     virtual void init(const string& filename, int lineno);
     virtual ~VFileLine() {}
     // ACCESSORS
-    virtual int lineno () const { return m_lineno; }	///< Return line number
-    virtual const string filename () const { return m_filename; }	///< Return filename
-    virtual const string filebasename () const;	///< Filename with any directory stripped
+    int lineno () const { return m_lineno; }	///< Return line number
+    void linenoIncInPlace() { m_lineno++; }	///< Increment line IN PLACE; normally use create() instead
+    const string filename () const { return m_filename; }	///< Return filename
+    const string filebasename () const;	///< Filename with any directory stripped
+    string lineDirectiveStrg(int enter_exit_level) const;
     // METHODS
     virtual void fatal(const string& msg);	///< Report a fatal error at given location
     virtual void error(const string& msg);	///< Report a error at given location
-    VFileLine* lineDirective(const char* textp);
+    VFileLine* lineDirective(const char* textp, int& enterExitRef);
     // STATIC METHODS
     static int numErrors() {return s_numErrors;}	///< Return total errors detected
 
