@@ -62,6 +62,8 @@ class VPreProcImp;
 #define VP_DEFFORM	309
 #define VP_STRIFY	310
 #define VP_BACKQUOTE	311
+#define VP_SYMBOL_JOIN	312
+#define VP_DEFREF_JOIN	313
 
 #define VP_PSL		350
 
